@@ -481,7 +481,44 @@ Arnolfini.showShareCounters = function ()
 				});
 }
 
+
+Arnolfini.frontPageColors = function ()
+{
+	var colors = []
+	
+	for (j in Arnolfini.colorMapping)
+	{
+		colors.push(Arnolfini.colorMapping[j]['class']);
+	}
+	
+	for (i in Arnolfini.colorMapping)
+	{
+		tag = Arnolfini.colorMapping[i];
+		
+		$("body.template-front_page_view .tag_" + tag['tag']).each(function () {
+			var taken = false;
+			
+			for (c in colors)
+			{
+				if ($(this).hasClass(colors[c]))
+				{
+					taken = true;
+				}
+			}
+			
+			if(!taken)
+			{
+				$(this).addClass(tag["class"]);
+				$(this).find(".imagelink").append($('<div class="colorTag '+tag["class"]+'">'+tag["tag"]+'</div>'));
+			}
+			
+		});
+	}
+}
+
 $(document).ready(function() {
+	$('#portal-globalnav li a').removeAttr('title');
+	Arnolfini.frontPageColors();
 	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
 	if ($(".columns").length > 0)
