@@ -95,6 +95,15 @@ class CommonBrowserView(BrowserView):
         secman = getSecurityManager()
         return secman.checkPermission(permission, item)
     
+    def getTagsAsClass(self, item):
+        
+        classes = []
+        
+        for tag in item.Subject:
+            classes.append("tag_%s"%tag)
+        
+        return " ".join(classes)
+    
     def slideshow(self, parent):
         """
         Creates a slideshow with the media from parent
